@@ -218,7 +218,10 @@ class Block(NamedTuple):
                 tokens[i] = tokens[i]._replace(src=tokens[i].src[diff:])
 
     def replace_condition(self, tokens: List[Token], new: List[Token]) -> None:
-        tokens[self.start:self.colon] = new
+        start = self.start
+        while tokens[start].name == 'UNIMPORTANT_WS':
+            start += 1
+        tokens[start:self.colon] = new
 
     def _trim_end(self, tokens: List[Token]) -> 'Block':
         """the tokenizer reports the end of the block at the beginning of
@@ -474,3 +477,10 @@ def find_comprehension_opening_bracket(i: int, tokens: List[Token]) -> int:
         return i
     else:  # pragma: no cover (<py38)
         return i
+
+
+def replace_list_comp_brackets(i: int, tokens: List[Token]) -> None:
+    start = find_comprehension_opening_bracket(i, tokens)
+    end = find_closing_bracket(tokens, start)
+    tokens[end] = Token('OP', ')')
+    tokens[start] = Token('OP', '(')
